@@ -440,7 +440,10 @@
 # endif
 #endif
 
-#if !defined(__GNUC__) && (defined(sparc) || defined(__sparc)) \
+#if defined(__SUNPRO_C) && defined(__i386)
+#   include "atomic_ops/sysdeps/generic_pthread.h"
+#   define AO_CAN_EMUL_CAS
+#elif !defined(__GNUC__) && (defined(sparc) || defined(__sparc)) \
     && !defined(AO_USE_PTHREAD_DEFS)
 # include "atomic_ops/sysdeps/sunc/sparc.h"
 # define AO_CAN_EMUL_CAS
